@@ -1,10 +1,10 @@
 package antlr;
 
 /* ANTLR Translator Generator
- * Project led by Terence Parr at http://www.jGuru.com
+ * Project led by Terence Parr at http://www.cs.usfca.edu
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/BaseAST.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/antlr/BaseAST.java#1 $
  */
 
 import antlr.collections.AST;
@@ -100,6 +100,14 @@ public abstract class BaseAST implements AST, Serializable {
     /** Is node t equal to this in terms of token type and text? */
     public boolean equals(AST t) {
         if (t == null) return false;
+		if ( (this.getText()==null && t.getText()!=null) ||
+			 (this.getText()!=null && t.getText()==null) )
+		{
+	        return false;
+		}
+		if ( this.getText()==null && t.getText()==null ) {
+			return this.getType() == t.getType();
+		}
         return this.getText().equals(t.getText()) &&
             this.getType() == t.getType();
     }
@@ -312,7 +320,8 @@ public abstract class BaseAST implements AST, Serializable {
         StringBuffer b = new StringBuffer();
         // if verbose and type name not same as text (keyword probably)
         if (verboseStringConversion &&
-            !getText().equalsIgnoreCase(tokenNames[getType()]) &&
+            getText() != null &&
+			!getText().equalsIgnoreCase(tokenNames[getType()]) &&
             !getText().equalsIgnoreCase(StringUtils.stripFrontBack(tokenNames[getType()], "\"", "\""))) {
             b.append('[');
             b.append(getText());
