@@ -1,10 +1,10 @@
 package antlr;
 
 /* ANTLR Translator Generator
- * Project led by Terence Parr at http://www.jGuru.com
+ * Project led by Terence Parr at http://www.cs.usfca.edu
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/ByteBuffer.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/antlr/ByteBuffer.java#1 $
  */
 
 /**A Stream of characters fed to the lexer from a InputStream that can
@@ -21,13 +21,13 @@ package antlr;
  */
 // SAS: added this class to handle Binary input w/ FileInputStream
 
-import java.io.InputStream;
 import java.io.IOException;
+import java.io.InputStream;
 
 public class ByteBuffer extends InputBuffer {
 
     // char source
-    transient InputStream input;
+    public transient InputStream input;
 
 
     /** Create a character buffer */
