@@ -1,12 +1,14 @@
 package antlr;
 
 /* ANTLR Translator Generator
- * Project led by Terence Parr at http://www.jGuru.com
+ * Project led by Terence Parr at http://www.cs.usfca.edu
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/CommonASTWithHiddenTokens.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/antlr/CommonASTWithHiddenTokens.java#1 $
  */
 
+import antlr.collections.AST;
+
 /** A CommonAST whose initialization copies hidden token
  *  information from the Token used to create a node.
  */
@@ -29,6 +31,13 @@ public class CommonASTWithHiddenTokens extends CommonAST {
         return hiddenBefore;
     }
 
+    public void initialize(AST t)
+    {
+	hiddenBefore = ((CommonASTWithHiddenTokens)t).getHiddenBefore();
+	hiddenAfter = ((CommonASTWithHiddenTokens)t).getHiddenAfter();
+	super.initialize(t);
+    }
+
     public void initialize(Token tok) {
         CommonHiddenStreamToken t = (CommonHiddenStreamToken)tok;
         super.initialize(t);
