@@ -1,10 +1,10 @@
 package antlr;
 
 /* ANTLR Translator Generator
- * Project led by Terence Parr at http://www.jGuru.com
+ * Project led by Terence Parr at http://www.cs.usfca.edu
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.5/antlr/DefineGrammarSymbols.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/antlr/DefineGrammarSymbols.java#1 $
  */
 
 import java.util.Hashtable;
@@ -472,6 +472,14 @@ public class DefineGrammarSymbols implements ANTLRGrammarParseBehavior {
         return t.getText();
     }
 
+    public int getHeaderActionLine(String name) {
+    	Token t = (Token)headerActions.get(name);
+    	if (t == null) {
+    		return 0;
+    	}
+    	return t.getLine();
+    }
+
     public void refInitAction(Token action) {
     }
 
@@ -678,6 +686,15 @@ public class DefineGrammarSymbols implements ANTLRGrammarParseBehavior {
                 tool.error("importVocab must be an identifier", grammar.getFilename(), value.getLine(), value.getColumn());
             }
         }
+		else if ( key.getText().equals("k") ) {
+			if( grammar instanceof TreeWalkerGrammar
+				&& ! value.getText().equals("1") ) {
+					tool.error("Treewalkers only support k=1", grammar.getFilename(), value.getLine(), value.getColumn());
+			}
+			else {
+	            grammar.setOption(key.getText(), value);
+			}
+		}
         else {
             // Forward all unrecognized options to the grammar
             grammar.setOption(key.getText(), value);
