@@ -1,10 +1,10 @@
 package antlr;
 
 /* ANTLR Translator Generator
- * Project led by Terence Parr at http://www.jGuru.com
+ * Project led by Terence Parr at http://www.cs.usfca.edu
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/LLkParser.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/antlr/LLkParser.java#1 $
  */
 
 import java.io.IOException;
@@ -44,7 +44,7 @@ public class LLkParser extends Parser {
      * For example, calling consume() 3 times when k=2, means that the first token
      * consumed will be overwritten with the 3rd.
      */
-    public void consume() {
+    public void consume() throws TokenStreamException {
         inputState.input.consume();
     }
 
