@@ -4,7 +4,7 @@ package antlr;
  * Project led by Terence Parr at http://www.jGuru.com
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/LexerSharedInputState.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/antlr/LexerSharedInputState.java#1 $
  */
 
 import java.io.Reader;
@@ -26,7 +26,7 @@ public class LexerSharedInputState {
     protected String filename;
 
     public int guessing = 0;
-
+    
     public LexerSharedInputState(InputBuffer inbuf) {
         input = inbuf;
     }
@@ -39,6 +39,34 @@ public class LexerSharedInputState {
         this(new CharBuffer(in));
     }
 
+    public String getFilename() {
+        return filename;
+    }
+
+    public InputBuffer getInput() {
+        return input;
+    }
+    
+    public int getLine()
+    {
+        return line;
+    }
+
+    public int getTokenStartColumn()
+    {
+        return tokenStartColumn;
+    }
+
+    public int getTokenStartLine()
+    {
+        return tokenStartLine;
+    }
+
+    public int getColumn()
+    {
+        return column;
+    }
+
     public void reset() {
         column = 1;
         line = 1;
@@ -49,3 +77,4 @@ public class LexerSharedInputState {
         input.reset();
     }
 }
+
