@@ -1,10 +1,10 @@
 package antlr;
 
 /* ANTLR Translator Generator
- * Project led by Terence Parr at http://www.jGuru.com
+ * Project led by Terence Parr at http://www.cs.usfca.edu
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/ParserGrammar.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/antlr/ParserGrammar.java#1 $
  */
 
 import java.util.Hashtable;
@@ -90,6 +90,10 @@ class ParserGrammar extends Grammar {
             super.setOption(key, value);
             return true;
         }
+        if (key.equals("className")) {
+            super.setOption(key, value);
+            return true;
+        }
         if (super.setOption(key, value)) {
             return true;
         }
