@@ -1,10 +1,10 @@
 package antlr;
 
 /* ANTLR Translator Generator
- * Project led by Terence Parr at http://www.jGuru.com
+ * Project led by Terence Parr at http://www.cs.usfca.edu
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/Token.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/antlr/Token.java#1 $
  */
 
 /** A token is minimally a token type.  Subclasses can add the text matched
@@ -19,7 +19,7 @@ public class Token implements Cloneable {
     public static final int SKIP = -1;
 
     // each Token has at least a token type
-    int type = INVALID_TYPE;
+    protected int type = INVALID_TYPE;
 
     // the illegal token object
     public static Token badToken = new Token(INVALID_TYPE, "<no text>");
@@ -73,6 +73,6 @@ public class Token implements Cloneable {
     }
 
     public String toString() {
-        return "[\"" + getText() + "\",<" + type + ">]";
+        return "[\"" + getText() + "\",<" + getType() + ">]";
     }
 }
