@@ -1,10 +1,10 @@
 package antlr;
 
 /* ANTLR Translator Generator
- * Project led by Terence Parr at http://www.jGuru.com
+ * Project led by Terence Parr at http://www.cs.usfca.edu
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/TokenBuffer.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/antlr/TokenBuffer.java#1 $
  */
 
 /**A Stream of Token objects fed to the parser from a Tokenizer that can
@@ -78,7 +78,7 @@ public class TokenBuffer {
     /** Get a lookahead token value */
     public final int LA(int i) throws TokenStreamException {
         fill(i);
-        return queue.elementAt(markerOffset + i - 1).type;
+        return queue.elementAt(markerOffset + i - 1).getType();
     }
 
     /** Get a lookahead token */
