@@ -5,12 +5,13 @@
  * Project led by Terence Parr at http://www.jGuru.com
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/lib/cpp/antlr/CharBuffer.hpp#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/lib/cpp/antlr/CharBuffer.hpp#1 $
  */
 
+#include <antlr/config.hpp>
+
 #include <istream>
 
-#include <antlr/config.hpp>
 #include <antlr/InputBuffer.hpp>
 
 #ifdef ANTLR_CXX_SUPPORTS_NAMESPACE
@@ -32,15 +33,16 @@ namespace antlr {
  */
 
 class ANTLR_API CharBuffer : public InputBuffer {
-private:
+public:
+	/// Create a character buffer
+	CharBuffer( ANTLR_USE_NAMESPACE(std)istream& input );
+	/// Get the next character from the stream
+	int getChar();
+
+protected:
 	// character source
 	ANTLR_USE_NAMESPACE(std)istream& input;
 
-public:
-	/// Create a character buffer
-	CharBuffer(ANTLR_USE_NAMESPACE(std)istream& input_);
-	/// Get the next character from the stream
-	int getChar();
 private:
 	// NOTE: Unimplemented
 	CharBuffer(const CharBuffer& other);
