@@ -5,7 +5,7 @@
  * Project led by Terence Parr at http://www.jGuru.com
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/lib/cpp/antlr/RecognitionException.hpp#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/lib/cpp/antlr/RecognitionException.hpp#1 $
  */
 
 # include <antlr/config.hpp>
@@ -21,41 +21,32 @@ namespace antlr
 		RecognitionException();
 		RecognitionException(const ANTLR_USE_NAMESPACE(std)string& s);
 		RecognitionException(const ANTLR_USE_NAMESPACE(std)string& s,
-									const ANTLR_USE_NAMESPACE(std)string& fileName_,
-									int line_,int column_);
+									const ANTLR_USE_NAMESPACE(std)string& fileName,
+									int line, int column );
 
 		virtual ~RecognitionException() throw()
 		{
 		}
 
 		/// Return file where mishap occurred.
-		virtual ANTLR_USE_NAMESPACE(std)string getFilename() const
+		virtual ANTLR_USE_NAMESPACE(std)string getFilename() const throw()
 		{
 			return fileName;
 		}
 		/**
 		 * @return the line number that this exception happened on.
 		 */
-		virtual int getLine() const
+		virtual int getLine() const throw()
 		{
 			return line;
 		}
 		/**
 		 * @return the column number that this exception happened on.
 		 */
-		virtual int getColumn() const
+		virtual int getColumn() const throw()
 		{
 			return column;
 		}
-#if 0
-		/**
-		 * @deprecated As of ANTLR 2.7.0
-		 */
-		virtual ANTLR_USE_NAMESPACE(std)string getErrorMessage() const
-		{
-			return getMessage();
-		}
-#endif
 
 		/// Return complete error message with line/column number info (if present)
 		virtual ANTLR_USE_NAMESPACE(std)string toString() const;
