@@ -5,7 +5,7 @@
  * Project led by Terence Parr at http://www.jGuru.com
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/lib/cpp/antlr/config.hpp#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/lib/cpp/antlr/config.hpp#1 $
  */
 
 /*
@@ -41,12 +41,20 @@
 // _MSC_VER == 1100 for Microsoft Visual C++ 5.0
 // _MSC_VER == 1200 for Microsoft Visual C++ 6.0
 // _MSC_VER == 1300 for Microsoft Visual C++ 7.0
-#if defined(_MSC_VER) && !defined(__ICL)
+#if defined(_MSC_VER)
+
+# if _MSC_VER < 1300
+#	define NOMINMAX
+#	pragma warning(disable : 4786)
+#	define min _cpp_min
+# endif
 
 // This warning really gets on my nerves.
 // It's the one about symbol longer than 256 chars, and it happens
 // all the time with STL.
 # pragma warning( disable : 4786 4231 )
+// this shuts up some DLL interface warnings for STL
+# pragma warning( disable : 4251 )
 
 # ifdef ANTLR_CXX_USE_STLPORT
 #	undef ANTLR_CXX_SUPPORTS_UNCAUGHT_EXCEPTION
@@ -71,35 +79,33 @@
 #	define ANTLR_API __declspec(dllimport)
 # endif
 
+# if ( _MSC_VER < 1200 )
+// supposedly only for MSVC5 and before...
+// Using vector<XXX> requires operator<(X,X) to be defined
+#	define NEEDS_OPERATOR_LESS_THAN
+# endif
+
 // VC6
 # if ( _MSC_VER == 1200 )
 #	undef ANTLR_ATOI_IN_STD
 # endif
 
-// These should be verified for newer MSVC's
+# if ( _MSC_VER < 1310 )
+// Supposedly only for MSVC7 and before...
 // Not allowed to put 'static const int XXX=20;' in a class definition
-# define NO_STATIC_CONSTS
-// Using vector<XXX> requires operator<(X,X) to be defined
-# define NEEDS_OPERATOR_LESS_THAN
+#	define NO_STATIC_CONSTS
+#	define NO_TEMPLATE_PARTS
+# endif
+
 // No strcasecmp in the C library (so use stricmp instead)
 // - Anyone know which is in which standard?
 # define NO_STRCASECMP
 # undef ANTLR_CCTYPE_NEEDS_STD
 
-// needed for CharScannerLiteralsLess
-# define NO_TEMPLATE_PARTS
-
 #endif	// End of Microsoft Visual C++
 
 /*}}}*/
 /******************************************************************************/
-
-// RK: belongs to what compiler?
-#if defined(__ICL)
-# define NO_STRCASECMP
-#endif
-
-/*****************************************************************************/
 /*{{{ SunPro Compiler (Using OBJECTSPACE STL)
  *****************************************************************************/
 #ifdef __SUNPRO_CC
@@ -178,8 +184,12 @@
 
 // No strcasecmp in the C library (so use stricmp instead)
 // - Anyone know which is in which standard?
+#if (defined(_AIX) && (__IBMCPP__ >= 600))
+# define NO_STATIC_CONSTS
+#else
 # define NO_STRCASECMP
 # undef ANTLR_CCTYPE_NEEDS_STD
+#endif
 
 #endif	// end IBM VisualAge C++
 /*}}}*/
@@ -255,6 +265,15 @@
 #endif
 /*}}}*/
 /*****************************************************************************/
+#ifdef __BORLANDC__
+# if  __BORLANDC__ >= 560
+#	include <ctype>
+#	include <stdlib>
+#	define ANTLR_CCTYPE_NEEDS_STD
+# else
+#	error "sorry, compiler is too old - consider an update."
+# endif
+#endif
 
 // Redefine these for backwards compatability..
 #undef ANTLR_BEGIN_NAMESPACE
