@@ -2,7 +2,7 @@
  * Project led by Terence Parr at http://www.jGuru.com
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/lib/cpp/src/CharScanner.cpp#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.6/lib/cpp/src/CharScanner.cpp#1 $
  */
 
 #include <iostream>
@@ -51,46 +51,6 @@ CharScanner::CharScanner( const LexerSharedInputState& state, bool case_sensitiv
 	setTokenObjectFactory(&CommonToken::factory);
 }
 
-void CharScanner::consume()
-{
-	if (inputState->guessing == 0)
-	{
-		int c = LA(1);
-		if (caseSensitive)
-		{
-			append(c);
-		}
-		else
-		{
-			// use input.LA(), not LA(), to get original case
-			// CharScanner.LA() would toLower it.
-			append(inputState->getInput().LA(1));
-		}
-
-		// RK: in a sense I don't like this automatic handling.
-		if (c == '\t')
-			tab();
-		else
-			inputState->column++;
-	}
-	inputState->getInput().consume();
-}
-
-//bool CharScanner::getCaseSensitiveLiterals() const
-//{ return caseSensitiveLiterals; }
-
-void CharScanner::panic()
-{
-	ANTLR_USE_NAMESPACE(std)cerr << "CharScanner: panic" << ANTLR_USE_NAMESPACE(std)endl;
-	exit(1);
-}
-
-void CharScanner::panic(const ANTLR_USE_NAMESPACE(std)string& s)
-{
-	ANTLR_USE_NAMESPACE(std)cerr << "CharScanner: panic: " << s.c_str() << ANTLR_USE_NAMESPACE(std)endl;
-	exit(1);
-}
-
 /** Report exception errors caught in nextToken() */
 void CharScanner::reportError(const RecognitionException& ex)
 {
